Flag

Enum Flag 

pub enum Flag {
    Zero,
    AddSubtract,
    HalfCarry,
    Carry,
}
Represents a CPU flag set after some instructions.

Note that many instructions leave flags alone, and others may repurpose them for side channel information.

Variants



Zero

The last arithmetic operation resulted in 0



AddSubtract

The last arithmetic operation was a subtract type operation 0 = Add, 1 = Sub



HalfCarry

The last arithmetic operation contained a carry between nibbles



Carry

The last arithmetic operation overflowed or underflowed

Implementations

Source

impl Flag

pub fn bit(&self) -> u8

Returns which bit of the flag register represents this flag