pub enum StackRegister {
BC,
DE,
HL,
SP,
}Expand description
Registers group that includes the stack register
This is mainly used for operations that do not operate on the stack, such as 16-bit transfers. This is because the stack target is implicit in operations that do operate on the stack
Variants