Cartridge

Struct Cartridge 

pub struct Cartridge {
    pub data: Vec<u8>,
    pub controller: ControllerEnum,
    pub target: TargetConsole,
}
A gameboy cartridge, including ROM data and memory controller

Fields

data: Vec<u8>controller: ControllerEnumtarget: TargetConsole

Implementations

Source

impl Cartridge

pub fn read(&self, loc: u16) -> CartridgeResult<u8>

Read a byte from address space controlled by the cart

pub fn write(&mut self, loc: u16, value: u8) -> CartridgeResult<()>

Write a byte to address space controlled by the cart

pub fn from_data(data: Vec<u8>) -> CartridgeResult<Cartridge>

Build a cartridge from ROM data