pub enum AccRegister {
BC,
DE,
HL,
AF,
}Expand description
16bit Register group that includes the accumalator register.
This is mainly used for operatiions that target the stack as it gives extra flexibility for targeting the stack. Note that writing to the F register in this manner only sets the high nibble of the F register.
Variants